@@ -2,10 +2,13 @@
 
 from pymeteobridgedata.api import MeteobridgeApiClient
 from pymeteobridgedata.exceptions import BadRequest, Invalid, NotAuthorized
+from pymeteobridgedata.data import ObservationDescription, DataLoggerDescription
 
 __all__ = [
     "Invalid",
     "NotAuthorized",
     "BadRequest",
     "MeteobridgeApiClient",
+    "ObservationDescription",
+    "DataLoggerDescription",
 ]
